Error

Trait Error 

pub trait Error: Error {
    // Required method
    fn kind(&self) -> ErrorKind;
}
Error trait.

This trait allows generic code to do limited inspecting of errors, to react differently to different kinds.

Required Methods

fn kind(&self) -> ErrorKind

Get the kind of this error.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Error for Infallible

Source

fn kind(&self) -> ErrorKind

Source

impl Error for Error

Available on crate feature std only.
Source

fn kind(&self) -> ErrorKind

Implementors